0.9.9 API documentation: GLM_GTX_raw_data

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Typedefs
GLM_GTX_raw_data
Experimental extensions

Include <glm/gtx/raw_data.hpp> to use the features of this extension. More...

## Typedefs
typedef detail::uint8 | byte
| Type for byte numbers. More...
typedef detail::uint32 | dword
| Type for dword numbers. More...
typedef detail::uint64 | qword
| Type for qword numbers. More...
typedef detail::uint16 | word
| Type for word numbers. More...

## Detailed Description

Include <glm/gtx/raw_data.hpp> to use the features of this extension.

Projection of a vector to other one

## Typedef Documentation

typedef detail::uint8 byte

Type for byte numbers.

From GLM_GTX_raw_data extension.

Definition at line 34 of file raw_data.hpp.

typedef detail::uint32 dword

Type for dword numbers.

From GLM_GTX_raw_data extension.

Definition at line 42 of file raw_data.hpp.

typedef detail::uint64 qword

Type for qword numbers.

From GLM_GTX_raw_data extension.

Definition at line 46 of file raw_data.hpp.

typedef detail::uint16 word

Type for word numbers.

From GLM_GTX_raw_data extension.

Definition at line 38 of file raw_data.hpp.